@@ -1,7 +1,7 @@
 /*
     Beekeeper dashboard
 
-    Copyright 2021 José Micó
+    Copyright 2023 José Micó
 
     This software uses the following libraries:
 
@@ -868,8 +868,16 @@ function BeekeeperClient () { return {
         this.mqtt.on('message', function (topic, message, packet) {
 
             let jsonrpc;
-            try { jsonrpc = JSON.parse( message.toString() ) }
-            catch (e) { throw `Received invalid JSON: ${e}` }
+            try {
+                if (message[0] == 0x78) {
+                    // Deflated JSON
+                    let json = pako.inflate(message, {to:'string'});
+                    jsonrpc = JSON.parse(json);
+                }
+                else {
+                    jsonrpc = JSON.parse(message.toString());
+                }
+            } catch (e) { throw `Received invalid JSON: ${e}` }
             This._debug(`Got  << ${message}`);
 
             const subscr_id = packet.properties.subscriptionIdentifier;
