@@ -3,15 +3,16 @@ package Beekeeper::Worker;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Beekeeper::Client ':worker';
 use Beekeeper::Logger ':log_levels';
 use Beekeeper::JSONRPC;
 
 use JSON::XS;
-use Time::HiRes;
-use Sys::Hostname;
+use Time::HiRes ();
+use Sys::Hostname ();
+use Compress::Raw::Zlib ();
 use Digest::MD5 'md5_base64';
 use Scalar::Util 'blessed';
 use Carp;
@@ -61,6 +62,7 @@ our $REPORT_STATUS_PERIOD = 5;
 our $UNSUBSCRIBE_LINGER   = 2;
 
 my %AUTH_TOKENS;
+my $DEFLATE;
 my $JSON;
 
 
@@ -87,7 +89,7 @@ sub new {
         pool_id         => $args{'pool_id'},
         bus_id          => $args{'bus_id'},
         config          => $args{'config'},
-        hostname        => hostname(),
+        hostname        => Sys::Hostname::hostname(),
         stop_cv         => undef,
         callbacks       => {},
         task_queue_high => [],
@@ -106,6 +108,8 @@ sub new {
     $JSON->allow_blessed;    # encode blessed references as null
     $JSON->convert_blessed;  # use TO_JSON methods to serialize objects
 
+    $DEFLATE = Compress::Raw::Zlib::Deflate->new( -AppendOutput => 1 );
+
     if (defined $SIG{TERM} && $SIG{TERM} eq 'DEFAULT') {
         # Stop working gracefully when TERM signal is received
         $SIG{TERM} = sub { $self->stop_working };
@@ -566,6 +570,14 @@ sub __drain_task_queue {
                     $json = $JSON->encode( $response );
                 }
 
+                if ($request->{_deflate_response} && length($json) > $request->{_deflate_response}) {
+                    my $compressed_json;
+                    $DEFLATE->deflate(\$json, $compressed_json);
+                    $DEFLATE->flush(\$compressed_json);
+                    $DEFLATE->deflateReset;
+                    $json = $compressed_json;
+                }
+
                 # Request is acknowledged as received just after sending the response. So, if
                 # the process is abruptly interrupted here, the broker will send the request to
                 # another worker and it will be executed twice (acking the request just before
@@ -666,6 +678,14 @@ sub __send_response {
         $self->{_WORKER}->{error_count}++;
     }
 
+    if ($request->{_deflate_response} && length($json) > $request->{_deflate_response}) {
+        my $compressed_json;
+        $DEFLATE->deflate(\$json, $compressed_json);
+        $DEFLATE->flush(\$compressed_json);
+        $DEFLATE->deflateReset;
+        $json = $compressed_json;
+    }
+
     $self->{_BUS}->publish(
         topic    => $request->{_mqtt_properties}->{'response_topic'},
         addr     => $request->{_mqtt_properties}->{'addr'},
@@ -1258,7 +1278,7 @@ José Micó, C<jose.mico@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015-2021 José Micó.
+Copyright 2015-2023 José Micó.
 
 This is free software; you can redistribute it and/or modify it under the same 
 terms as the Perl 5 programming language itself.
